==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Arc/ArcTPR/ts/ArcTPR_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>ArcTPR</name>
    <message>
        <location filename="../ArcTPR.js" line="+79"/>
        <source>Choose line, arc, circle or ellipse</source>
        <translation>Izberi črto, lok, krog ali elipso</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Point on arc</source>
        <translation>Točka na loku</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Choose solution</source>
        <translation>Izberite rešitev</translation>
    </message>
    <message>
        <location line="+123"/>
        <location line="+65"/>
        <source>No solution</source>
        <translation>Ni rešitve</translation>
    </message>
    <message>
        <location filename="../ArcTPR.ui" line="+17"/>
        <source>Radius:</source>
        <translation>Polmer:</translation>
    </message>
    <message>
        <location filename="../ArcTPRInit.js" line="+2"/>
        <source>&amp;Tangent, Point, Radius</source>
        <translation>&amp;Tangenta, točka, polmer</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc tangential to entity, through point with radius</source>
        <translation>Nariši lok tangencialno na entiteto, skozi točko z polmerom</translation>
    </message>
</context>
<context>
    <name>Circle2TP</name>
    <message>
        <source>First line, arc or circle</source>
        <translation type="vanished">Prva črta, lok ali krog</translation>
    </message>
    <message>
        <source>Second line, arc or circle</source>
        <translation type="vanished">Druga črta, lok ali krog</translation>
    </message>
    <message>
        <source>Point on circle line</source>
        <translation type="vanished">Točka na črti kroga</translation>
    </message>
    <message>
        <source>Choose solution</source>
        <translation type="vanished">Izberite rešitev</translation>
    </message>
    <message>
        <source>No solution</source>
        <translation type="vanished">Ni rešitve</translation>
    </message>
    <message>
        <source>Point, 2 Tan&amp;gents</source>
        <translation type="vanished">Točka, 2 Tan&amp;genti</translation>
    </message>
    <message>
        <source>Draw circle tangential to two entities, through point</source>
        <translation type="vanished">Nariši krog tangencialno na dve entiteti, skozi točko</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Arc/ArcTPR/ts/ArcTPR_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>ArcTPR</name>
    <message>
        <location filename="../ArcTPR.js" line="+79"/>
        <source>Choose line, arc, circle or ellipse</source>
        <translation>Izberi črto, lok, krog ali elipso</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Point on arc</source>
        <translation>Točka na loku</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Choose solution</source>
        <translation>Izberite rešitev</translation>
    </message>
    <message>
        <location line="+123"/>
        <location line="+65"/>
        <source>No solution</source>
        <translation>Ni rešitve</translation>
    </message>
    <message>
        <location filename="../ArcTPR.ui" line="+17"/>
        <source>Radius:</source>
        <translation>Polmer:</translation>
    </message>
    <message>
        <location filename="../ArcTPRInit.js" line="+2"/>
        <source>&amp;Tangent, Point, Radius</source>
        <translation>&amp;Tangenta, točka, polmer</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc tangential to entity, through point with radius</source>
        <translation>Nariši lok tangencialno na entiteto, skozi točko s polmerom</translation>
    </message>
</context>
<context>
    <name>Circle2TP</name>
    <message>
        <source>First line, arc or circle</source>
        <translation type="vanished">Prva črta, lok ali krog</translation>
    </message>
    <message>
        <source>Second line, arc or circle</source>
        <translation type="vanished">Druga črta, lok ali krog</translation>
    </message>
    <message>
        <source>Point on circle line</source>
        <translation type="vanished">Točka na črti kroga</translation>
    </message>
    <message>
        <source>Choose solution</source>
        <translation type="vanished">Izberite rešitev</translation>
    </message>
    <message>
        <source>No solution</source>
        <translation type="vanished">Ni rešitve</translation>
    </message>
    <message>
        <source>Point, 2 Tan&amp;gents</source>
        <translation type="vanished">Točka, 2 Tan&amp;genti</translation>
    </message>
    <message>
        <source>Draw circle tangential to two entities, through point</source>
        <translation type="vanished">Nariši krog tangencialno na dve entiteti, skozi točko</translation>
    </message>
</context>
</TS>
